@@ -1,5 +1,5 @@
 // -*- c++ -*-
-/* $Id: error.cc 277 2006-05-10 08:05:04Z murrayc $ */
+/* $Id: error.cc 749 2008-12-10 14:23:33Z jjongsma $ */
 
 /* error.cc
  *
@@ -20,8 +20,9 @@
  * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-#include <glib/gerror.h>
-#include <glib/gmessages.h>
+//#include <glib/gtestutils.h> //For g_assert() in glib >= 2.15.0
+//#include <glib/gmessages.h> //For g_assert() in glib < 2.15.0
+#include <glib.h> //For g_assert() in all versions of glib.
 
 #include <map>
 #include <glibmmconfig.h>
