@@ -1,5 +1,5 @@
 // -*- c++ -*-
-/* $Id: pattern.cc 270 2006-04-14 10:13:46Z  $ */
+/* $Id: pattern.cc 749 2008-12-10 14:23:33Z jjongsma $ */
 
 /* pattern.cc
  *
@@ -20,7 +20,7 @@
  * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-#include <glib/gpattern.h>
+#include <glib.h>
 #include <glibmm/pattern.h>
 
 
